# Small fish 文件加密命令行

![Small-fish](http://47.108.189.192:8989/download?filename=/www/wwwroot/PYDOME/Cherry/img/63.jpg)

# 作者

***PYmili***

![PYmili](http://47.108.189.192/Pymili/image/PYmili.jpg)

**安装好Smail-fish命令行后就可以打开windows终端输入一下命令***

`<Small-fish -h>`

**即可查看所有命令使用方法***

